/*******************************************************************************
* File Name: Bootloadable_Status.c  
* Version 2.20
*
* Description:
*  This file contains APIs to set up the Pins component for low power modes.
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Bootloadable_Status.h"

static Bootloadable_Status_BACKUP_STRUCT  Bootloadable_Status_backup = {0u, 0u, 0u};


/*******************************************************************************
* Function Name: Bootloadable_Status_Sleep
****************************************************************************//**
*
* \brief Stores the pin configuration and prepares the pin for entering chip 
*  deep-sleep/hibernate modes. This function must be called for SIO and USBIO
*  pins. It is not essential if using GPIO or GPIO_OVT pins.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None 
*  
* \sideeffect
*  For SIO pins, this function configures the pin input threshold to CMOS and
*  drive level to Vddio. This is needed for SIO pins when in device 
*  deep-sleep/hibernate modes.
*
* \funcusage
*  \snippet Bootloadable_Status_SUT.c usage_Bootloadable_Status_Sleep_Wakeup
*******************************************************************************/
void Bootloadable_Status_Sleep(void)
{
    #if defined(Bootloadable_Status__PC)
        Bootloadable_Status_backup.pcState = Bootloadable_Status_PC;
    #else
        #if (CY_PSOC4_4200L)
            /* Save the regulator state and put the PHY into suspend mode */
            Bootloadable_Status_backup.usbState = Bootloadable_Status_CR1_REG;
            Bootloadable_Status_USB_POWER_REG |= Bootloadable_Status_USBIO_ENTER_SLEEP;
            Bootloadable_Status_CR1_REG &= Bootloadable_Status_USBIO_CR1_OFF;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(Bootloadable_Status__SIO)
        Bootloadable_Status_backup.sioState = Bootloadable_Status_SIO_REG;
        /* SIO requires unregulated output buffer and single ended input buffer */
        Bootloadable_Status_SIO_REG &= (uint32)(~Bootloadable_Status_SIO_LPM_MASK);
    #endif  
}


/*******************************************************************************
* Function Name: Bootloadable_Status_Wakeup
****************************************************************************//**
*
* \brief Restores the pin configuration that was saved during Pin_Sleep().
*
* For USBIO pins, the wakeup is only triggered for falling edge interrupts.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None
*  
* \funcusage
*  Refer to Bootloadable_Status_Sleep() for an example usage.
*******************************************************************************/
void Bootloadable_Status_Wakeup(void)
{
    #if defined(Bootloadable_Status__PC)
        Bootloadable_Status_PC = Bootloadable_Status_backup.pcState;
    #else
        #if (CY_PSOC4_4200L)
            /* Restore the regulator state and come out of suspend mode */
            Bootloadable_Status_USB_POWER_REG &= Bootloadable_Status_USBIO_EXIT_SLEEP_PH1;
            Bootloadable_Status_CR1_REG = Bootloadable_Status_backup.usbState;
            Bootloadable_Status_USB_POWER_REG &= Bootloadable_Status_USBIO_EXIT_SLEEP_PH2;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(Bootloadable_Status__SIO)
        Bootloadable_Status_SIO_REG = Bootloadable_Status_backup.sioState;
    #endif
}


/* [] END OF FILE */
